serve_file

Function serve_file 

fn serve_file(path: &str) -> Response
Serves a static file from the embedded assets.

Arguments

  • path - The path to the file within the embedded assets.

Returns

An Axum Response containing the file content or a 404 error.